This message is emitted when a class which is decorated with `final` is subclassed; the decorator indicates that the class is not intended to be extended.

Note this message can't be emitted when using Python < 3.8.
